
.. If you created a package, create one automodule per module in the package.

.. If your library file(s) are nested in a directory (e.g. /adafruit_foo/foo.py)
.. use this format as the module name: "adafruit_foo.foo"

.. automodule:: adafruit_lsm6ds
   :members:
   :exclude-members: CV, AccelRange, GyroRange, AccelHPF, Rate
   :member-order: bysource


.. automodule:: adafruit_lsm6ds.ism330dhcx
   :members:

.. automodule:: adafruit_lsm6ds.lsm6ds33
   :members:

.. automodule:: adafruit_lsm6ds.lsm6dso32
   :members:

.. automodule:: adafruit_lsm6ds.lsm6dsox
   :members:
